@@ -70,9 +70,12 @@ def heal(packagename: str, t: str) -> None:  # pragma: no cover
         check=True,
     )
     subprocess.run([f"mypy --strict {packagename}"], shell=True, check=True)
-    subprocess.run(
-        [f"python -m pylint -f parseable {packagename}"], shell=True, check=True
-    )
+    try:
+        subprocess.run(
+            [f"python -m pylint -f parseable {packagename}"], shell=True, check=True
+        )
+    except Exception as exc:
+        print(str(exc))
     subprocess.run(
         [f"prettify-py format-dir {packagename}"], shell=True, check=True)
     if t == "y":
@@ -137,7 +140,7 @@ def say_end_message() -> None:
         f"Thank you for using Lia."
         f"{anatomical_heart} Lia is an open-source CI/CD tool "
         f"that eliminates the Fel {mechanical_arm}\n"
-        f" Copyright © 2023 Soul Twin Studios {call_me_hand}, "
+        f"Copyright © 2023 Soul Twin Studios {call_me_hand}, "
         f"a subsidiary of SailBlack Inc. {sailing_ship}"
         f"For more nice things follow us on www.codeberg.org/sail.black"
     )
