@@ -7,7 +7,7 @@ pyproject.toml or setup.py
 """
 
 
-def speak_veritas():
+def speak_veritas() -> None:
     """
     With this function, lia asks you about the details
     of your package.
